==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/OpenSCAD/Resources/translations/OpenSCAD_kab.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="kab" sourcelanguage="en">
  <context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="14"/>
      <source>General settings</source>
      <translation>Paramètres généraux</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="26"/>
      <source>General OpenSCAD Settings</source>
      <translation>Réglages généraux de OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="34"/>
      <source>OpenSCAD executable</source>
      <translation>Exécutable OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="65"/>
      <source>OpenSCAD import</source>
      <translation>importation OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="93"/>
      <source>Use ViewProvider in Tree View</source>
      <translation>Utiliser les ViewProviders dans l'arborescence</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="110"/>
      <source>If this is checked, Multmatrix Object will be Parametric</source>
      <translation>Si cette case est cochée, les objets Multimatrix seront paramétriques</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="113"/>
      <source>Use Multmatrix Feature</source>
      <translation>Utiliser la fonction Multimatrix</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="153"/>
      <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
      <translation>Le nombre maximal de faces d'un polygone, prisme ou tronc. Si fn est supérieur à cette valeur, l'objet est considéré circulaire. Une valeur de 0 signifie aucune limite</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="133"/>
      <source>Maximum number of faces for polygons (fn)</source>
      <translation>Nombre maximum de faces pour les polygones (fn)</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="177"/>
      <source>OpenSCAD export</source>
      <translation>Exportation OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="185"/>
      <source>maximum fragment size</source>
      <translation>taille maximale de fragment</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="208"/>
      <source>angular (fa)</source>
      <translation>angulaire (fa)</translation>
    </message>
    <message encoding="UTF-8">
      <location filename="../ui/openscadprefs-base.ui" line="218"/>
      <source>°</source>
      <translation>°</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="250"/>
      <source>size (fs)</source>
      <translation>taille (fs)</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="278"/>
      <source>mm</source>
      <translation type="unfinished">mm</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="304"/>
      <source>convexity</source>
      <translation>convexité</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="341"/>
      <source>Mesh fallback</source>
      <translation>Maillage de secours</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="383"/>
      <source>Deflection</source>
      <translation>Déflexion</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="386"/>
      <source>deflection</source>
      <translation>déflexion</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="393"/>
      <source>Triangulation settings</source>
      <translation>Paramètres de triangulation</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="90"/>
      <source>If this is checked, Features will claim their children in the tree view</source>
      <translation>Si cette case est cochée, les objets revendiqueront leurs enfants dans l'arborescence</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="73"/>
      <source>Print debug information in the Console</source>
      <translation>Afficher les informations de débogage dans la Console</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="47"/>
      <source>The path to the OpenSCAD executable</source>
      <translation type="unfinished">The path to the OpenSCAD executable</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="215"/>
      <source>Minimum angle for a fragment</source>
      <translation type="unfinished">Minimum angle for a fragment</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="272"/>
      <source>Minimum size of a fragment</source>
      <translation type="unfinished">Minimum size of a fragment</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="145"/>
      <source>Convert Edges to Faces</source>
      <translation>Convertir les arêtes en faces</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="224"/>
      <source>Please select 3 objects first</source>
      <translation>Veuillez d'abord sélectionner 3 objets</translation>
    </message>
    <message>
      <location filename="../../importCSG.py" line="1204"/>
      <source>Unsupported Function</source>
      <translation>Fonction non supportée</translation>
    </message>
    <message>
      <location filename="../../importCSG.py" line="1204"/>
      <source>Press OK</source>
      <translation>Appuyez sur OK</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="268"/>
      <source>Add</source>
      <translation type="unfinished">Add</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="269"/>
      <source>Clear</source>
      <translation type="unfinished">Clear</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="270"/>
      <source>as Mesh</source>
      <translation>comme Maillage</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="271"/>
      <source>Add OpenSCAD Element</source>
      <translation>Ajouter un élément OpenSCAD</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="344"/>
      <source>Perform</source>
      <translation>Effectuer</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="345"/>
      <source>Mesh Boolean</source>
      <translation>Opération booléenne avec maillage</translation>
    </message>
    <message>
      <location filename="../../OpenSCADUtils.py" line="585"/>
      <source>Error all shapes must be either 2D or both must be 3D</source>
      <translation>Erreur les formes doivent être soit toutes 3D, soit toutes 2D</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="95"/>
      <source>Unable to explode %s</source>
      <translation>Impossible d'exploser %s</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="386"/>
      <source>Add OpenSCAD Element...</source>
      <translation>Ajouter un élément OpenSCAD...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="388"/>
      <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
      <translation>Ajouter un élément OpenSCAD par la saisie de code OpenSCAD et l'exécution du binaire OpenSCAD</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="122"/>
      <source>Color Shapes</source>
      <translation>Colorer les formes</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="124"/>
      <source>Color Shapes by validity and type</source>
      <translation>Colorer les formes par la validité et le type</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="143"/>
      <source>Convert Edges To Faces</source>
      <translation>Convertir les arêtes en faces</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="204"/>
      <source>Expand Placements</source>
      <translation>Développer les placements</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="206"/>
      <source>Expand all placements downwards the FeatureTree</source>
      <translation>Développer tous les placements vers le bas dans l'arborescence</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="104"/>
      <source>Explode Group</source>
      <translation>Dégrouper</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="106"/>
      <source>Remove fusion, apply placement to children, and color randomly</source>
      <translation type="unfinished">Remove fusion, apply placement to children, and color randomly</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Hull</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="421"/>
      <source>Hull</source>
      <translation>Enveloppe</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="423"/>
      <source>Perform Hull</source>
      <translation>Effectuer l'enveloppe convexe</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="185"/>
      <source>Increase Tolerance Feature</source>
      <translation>Augmenter la  tolérance</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="187"/>
      <source>Create Feature that allows to increase the tolerance</source>
      <translation>Créez une fonction qui permet d'augmenter la tolérance</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="400"/>
      <source>Mesh Boolean...</source>
      <translation>Opération booléenne avec Maillage...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="402"/>
      <source>Export objects as meshes and use OpenSCAD to perform a boolean operation</source>
      <translation type="unfinished">Export objects as meshes and use OpenSCAD to perform a boolean operation</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Minkowski</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="442"/>
      <source>Minkowski</source>
      <translation>Somme de Minkowski</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="444"/>
      <source>Perform Minkowski</source>
      <translation>Appliquer une Somme de Minkowski</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="164"/>
      <source>Refine Shape Feature</source>
      <translation>Fonction d'affinage de la forme</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="166"/>
      <source>Create Refine Shape Feature</source>
      <translation>Créer une fonction d'affinage de la forme</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="243"/>
      <source>Remove Objects and their Children</source>
      <translation>Supprimer les objets et leurs enfants</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="245"/>
      <source>Removes the selected objects and all children that are not referenced from other objects</source>
      <translation>Supprime les objets sélectionnés et tous les enfants qui ne sont pas référencés par d'autres objets</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="228"/>
      <source>Replace Object</source>
      <translation>Remplacer l'objet</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="230"/>
      <source>Replace an object in the Feature Tree. Please select old, new, and parent object</source>
      <translation type="unfinished">Replace an object in the Feature Tree. Please select old, new, and parent object</translation>
    </message>
  </context>
  <context>
    <name>Workbech</name>
    <message>
      <location filename="../../InitGui.py" line="80"/>
      <source>OpenSCAD Part tools</source>
      <translation>Outils de pièces OpenSCAD</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../InitGui.py" line="78"/>
      <source>OpenSCADTools</source>
      <translation>Outils OpenSCAD</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.2+dfsg1.orig.tar.xz: FreeCAD-0.19.2/src/Mod/OpenSCAD/Resources/translations/OpenSCAD_kab.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="1.1" language="kab" sourcelanguage="en">
  <context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
      <location filename="openscadprefs-base.ui" line="14"/>
      <source>General settings</source>
      <translation>Paramètres généraux</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="26"/>
      <source>General OpenSCAD Settings</source>
      <translation>Réglages généraux de OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="34"/>
      <source>OpenSCAD executable</source>
      <translation>Exécutable OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="65"/>
      <source>OpenSCAD import</source>
      <translation>importation OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="93"/>
      <source>Use ViewProvider in Tree View</source>
      <translation>Utiliser les ViewProviders dans l'arborescence</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="110"/>
      <source>If this is checked, Multmatrix Object will be Parametric</source>
      <translation>Si cette case est cochée, les objets Multimatrix seront paramétriques</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="113"/>
      <source>Use Multmatrix Feature</source>
      <translation>Utiliser la fonction Multimatrix</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="153"/>
      <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
      <translation>Le nombre maximal de faces d'un polygone, prisme ou tronc. Si fn est supérieur à cette valeur, l'objet est considéré circulaire. Une valeur de 0 signifie aucune limite</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="133"/>
      <source>Maximum number of faces for polygons (fn)</source>
      <translation>Nombre maximum de faces pour les polygones (fn)</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="177"/>
      <source>OpenSCAD export</source>
      <translation>Exportation OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="185"/>
      <source>maximum fragment size</source>
      <translation>taille maximale de fragment</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="208"/>
      <source>angular (fa)</source>
      <translation>angulaire (fa)</translation>
    </message>
    <message encoding="UTF-8">
      <location filename="openscadprefs-base.ui" line="218"/>
      <source>°</source>
      <translation>°</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="250"/>
      <source>size (fs)</source>
      <translation>taille (fs)</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="278"/>
      <source>mm</source>
      <translation type="unfinished">mm</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="304"/>
      <source>convexity</source>
      <translation>convexité</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="341"/>
      <source>Mesh fallback</source>
      <translation>Maillage de secours</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="383"/>
      <source>Deflection</source>
      <translation>Déflexion</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="386"/>
      <source>deflection</source>
      <translation>déflexion</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="393"/>
      <source>Triangulation settings</source>
      <translation>Paramètres de triangulation</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="90"/>
      <source>If this is checked, Features will claim their children in the tree view</source>
      <translation>Si cette case est cochée, les objets revendiqueront leurs enfants dans l'arborescence</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="73"/>
      <source>Print debug information in the Console</source>
      <translation>Afficher les informations de débogage dans la Console</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="47"/>
      <source>The path to the OpenSCAD executable</source>
      <translation type="unfinished">The path to the OpenSCAD executable</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="215"/>
      <source>Minimum angle for a fragment</source>
      <translation type="unfinished">Minimum angle for a fragment</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="272"/>
      <source>Minimum size of a fragment</source>
      <translation type="unfinished">Minimum size of a fragment</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD</name>
    <message>
      <location filename="OpenSCADCommands.py" line="149"/>
      <source>Convert Edges to Faces</source>
      <translation>Convertir les arêtes en faces</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="309"/>
      <source>Please select 3 objects first</source>
      <translation>Veuillez d'abord sélectionner 3 objets</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1226"/>
      <source>Unsupported Function</source>
      <translation>Fonction non supportée</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1226"/>
      <source>Press OK</source>
      <translation>Appuyez sur OK</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="347"/>
      <source>Add</source>
      <translation type="unfinished">Add</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="348"/>
      <source>Clear</source>
      <translation type="unfinished">Clear</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="349"/>
      <source>as Mesh</source>
      <translation>comme Maillage</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="350"/>
      <source>Add OpenSCAD Element</source>
      <translation>Ajouter un élément OpenSCAD</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="423"/>
      <source>Perform</source>
      <translation>Effectuer</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="424"/>
      <source>Mesh Boolean</source>
      <translation>Opération booléenne avec maillage</translation>
    </message>
    <message>
      <location filename="OpenSCADUtils.py" line="623"/>
      <source>Error all shapes must be either 2D or both must be 3D</source>
      <translation>Erreur les formes doivent être soit toutes 3D, soit toutes 2D</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="102"/>
      <source>Unable to explode %s</source>
      <translation>Impossible d'exploser %s</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
      <location filename="OpenSCADCommands.py" line="464"/>
      <source>Add OpenSCAD Element...</source>
      <translation>Ajouter un élément OpenSCAD...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="468"/>
      <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
      <translation>Ajouter un élément OpenSCAD par la saisie de code OpenSCAD et l'exécution du binaire OpenSCAD</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
      <location filename="OpenSCADCommands.py" line="126"/>
      <source>Color Shapes</source>
      <translation>Colorer les formes</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="129"/>
      <source>Color Shapes by validity and type</source>
      <translation>Colorer les formes par la validité et le type</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
      <location filename="OpenSCADCommands.py" line="146"/>
      <source>Convert Edges To Faces</source>
      <translation>Convertir les arêtes en faces</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
      <location filename="OpenSCADCommands.py" line="291"/>
      <source>Expand Placements</source>
      <translation>Développer les placements</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="294"/>
      <source>Expand all placements downwards the FeatureTree</source>
      <translation>Développer tous les placements vers le bas dans l'arborescence</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
      <location filename="OpenSCADCommands.py" line="110"/>
      <source>Explode Group</source>
      <translation>Dégrouper</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="113"/>
      <source>Remove fusion, apply placement to children, and color randomly</source>
      <translation type="unfinished">Remove fusion, apply placement to children, and color randomly</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Hull</name>
    <message>
      <location filename="OpenSCADCommands.py" line="497"/>
      <source>Hull</source>
      <translation>Enveloppe</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="500"/>
      <source>Perform Hull</source>
      <translation>Effectuer l'enveloppe convexe</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="274"/>
      <source>Increase Tolerance Feature</source>
      <translation>Augmenter la  tolérance</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="277"/>
      <source>Create Feature that allows to increase the tolerance</source>
      <translation>Créez une fonction qui permet d'augmenter la tolérance</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
      <location filename="OpenSCADCommands.py" line="477"/>
      <source>Mesh Boolean...</source>
      <translation>Opération booléenne avec Maillage...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="481"/>
      <source>Export objects as meshes and use OpenSCAD to perform a boolean operation</source>
      <translation type="unfinished">Export objects as meshes and use OpenSCAD to perform a boolean operation</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Minkowski</name>
    <message>
      <location filename="OpenSCADCommands.py" line="516"/>
      <source>Minkowski</source>
      <translation>Somme de Minkowski</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="519"/>
      <source>Perform Minkowski</source>
      <translation>Appliquer une Somme de Minkowski</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MirrorMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="195"/>
      <source>Mirror Mesh Feature...</source>
      <translation type="unfinished">Mirror Mesh Feature...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="198"/>
      <source>Create Mirror Mesh Feature</source>
      <translation type="unfinished">Create Mirror Mesh Feature</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="165"/>
      <source>Refine Shape Feature</source>
      <translation>Fonction d'affinage de la forme</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="168"/>
      <source>Create Refine Shape Feature</source>
      <translation>Créer une fonction d'affinage de la forme</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
      <location filename="OpenSCADCommands.py" line="324"/>
      <source>Remove Objects and their Children</source>
      <translation>Supprimer les objets et leurs enfants</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="327"/>
      <source>Removes the selected objects and all children that are not referenced from other objects</source>
      <translation>Supprime les objets sélectionnés et tous les enfants qui ne sont pas référencés par d'autres objets</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
      <location filename="OpenSCADCommands.py" line="312"/>
      <source>Replace Object</source>
      <translation>Remplacer l'objet</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="315"/>
      <source>Replace an object in the Feature Tree. Please select old, new, and parent object</source>
      <translation type="unfinished">Replace an object in the Feature Tree. Please select old, new, and parent object</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ResizeMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="254"/>
      <source>Resize Mesh Feature...</source>
      <translation type="unfinished">Resize Mesh Feature...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="258"/>
      <source>Create Resize Mesh Feature</source>
      <translation type="unfinished">Create Resize Mesh Feature</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ScaleMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="224"/>
      <source>Scale Mesh Feature...</source>
      <translation type="unfinished">Scale Mesh Feature...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="228"/>
      <source>Create Scale Mesh Feature</source>
      <translation type="unfinished">Create Scale Mesh Feature</translation>
    </message>
  </context>
  <context>
    <name>Workbech</name>
    <message>
      <location filename="InitGui.py" line="83"/>
      <source>OpenSCAD Part tools</source>
      <translation>Outils de pièces OpenSCAD</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="InitGui.py" line="81"/>
      <source>OpenSCADTools</source>
      <translation>Outils OpenSCAD</translation>
    </message>
  </context>
</TS>
